/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.api;

import org.ow2.petals.admin.api.exception.RegistryAdministrationException;
import org.ow2.petals.admin.api.exception.RegistryRegexpPatternException;
import org.ow2.petals.admin.registry.RegistryView;

/**
 * 
 * @author Nicolas Oddoux - EBM WebSourcing
 */
public interface RegistryAdministration {

    /**
     * Return the registry content filtered according to the provided regular expressions.
     * 
     * @param containerNameRegex
     *            A regexp filtering endpoint on its container name If <code>null</code>, the regexp '<code>.*</code>'
     *            matching all containers is used.
     * @param endpointNameRegex
     *            A regexp filtering endpoint name. If <code>null</code>, the regexp '<code>.*</code>' matching all
     *            endpoints is used.
     * @param serviceNameRegex
     *            A regexp filtering service name If <code>null</code>, the regexp '<code>.*</code>' matching all
     *            services is used.
     * @param interfaceNameRegex
     *            A regexp filtering interface name If <code>null</code>, the regexp '<code>.*</code>' matching all
     *            interfaces is used.
     * @return The registry content filtered.
     * @throws RegistryRegexpPatternException
     *             A regexp is invalid
     * @throws RegistryAdministrationException
     *             An error occurs getting the registry content.
     */
    public RegistryView getRegistryContent(final String containerNameRegex, final String endpointNameRegex,
            final String serviceNameRegex, final String interfaceNameRegex) throws RegistryRegexpPatternException,
            RegistryAdministrationException;

}
