/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.topology;

import java.util.Map;


/**
 * 
 * @author Nicolas Oddoux - EBM WebSourcing
 */
public class Container {

    public enum PortType {
        
        JMX("JMX port"),
        TCP_TRANSPORT("TCP port");
        
        private String displayValue;
        
        PortType(final String displayValue) {
            this.displayValue = displayValue;
        }

        public String toString() {
            return this.displayValue;
        }
    }

    public enum State {

        STARTED("Started"), STOPPED("Stopped"), UNKNOWN("Unknown");

        private String displayValue;

        State(final String displayValue) {
            this.displayValue = displayValue;
        }
    
        public String toString(){
            return this.displayValue;
        }
    }
    
    private final String containerName;

    private final String host;
    
    private final Map<PortType, Integer> ports;
    
    private final String jmxUsername;

    private final String jmxPassword;

    private final State state;

    public Container(final String containerName, final String host, final Map<PortType, Integer> ports,
            final String jmxUsername, final String jmxPassword, final State state) {
        assert  containerName != null;
        assert  host != null;
        assert  ports != null;
        
        this.containerName = containerName;
        this.host = host;
        this.ports = ports;
        this.jmxPassword = jmxPassword;
        this.jmxUsername = jmxUsername;
        this.state = state;
    }

    public String getContainerName() {
        return this.containerName;
    }
    
    public String getHost() {
        return this.host;
    }
    
    public Map<PortType, Integer> getPorts() {
        return this.ports;
    }

    public String getJmxUsername() {
        return this.jmxUsername;
    }

    public String getJmxPassword() {
        return this.jmxPassword;
    }

    public State getState() {
        return this.state;
    }
}